<?php
require_once 'stimulsoft/helper.php';
?>

<!DOCTYPE html>
<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
    <link rel="shortcut icon" href="favicon.ico" type="image/x-icon">
    <title>Stimulsoft Reports.PHP - Viewer</title>
    <style>html, body {
            font-family: sans-serif;
        }</style>

    <!-- Stimulsoft Reports.JS -->
    <script src="scripts/stimulsoft.reports.js" type="text/javascript"></script>

    <!-- Stimulsoft JS Viewer -->
    <script src="scripts/stimulsoft.viewer.js" type="text/javascript"></script>

    <?php
    // Add JavaScript helpers and init options to work with the PHP server
    // You can change the handler file and timeout if required
    StiHelper::init('handler.php', 30);
    ?>

    <script type="text/javascript">
        var options = new Stimulsoft.Viewer.StiViewerOptions();
        options.toolbar.showSendEmailButton = true;
        options.toolbar.displayMode = Stimulsoft.Viewer.StiToolbarDisplayMode.Separated;
        options.appearance.fullScreenMode = true;
        options.appearance.scrollbarsMode = true;
        options.height = "600px"; // Height for non-fullscreen mode

        var viewer = new Stimulsoft.Viewer.StiViewer(options, "StiViewer", false);

        function loadJsonFile(filePath) {
            return fetch(filePath)
                .then(response => {
                    if (!response.ok) {
                        throw new Error('err net');
                    }
                    return response.json();
                })
                .catch(error => {
                    console.error('error fetch: ', error);
                });
        }

        const jsonFilePath = 'reports/SimpleList.json';
        const xmlFilePath = 'reports/SimpleList.xml';

        var report = new Stimulsoft.Report.StiReport();
        var n = Stimulsoft.System.Guid.newGuid().toString().substr(0, 8);
        report.loadFile("reports/SimpleList.mrt" + "?n=" + n);
        report.culture = "de-DE";
        var dataSet = new Stimulsoft.System.Data.DataSet("data");

        viewer.renderHtml("viewerContent");

        loadJsonFile(jsonFilePath).then(reportdata => {
            dataSet.readJson(reportdata);
            report.regData(dataSet.dataSetName, "", dataSet);
        });

        var saveMenu = viewer.jsObject.controls.menus.saveMenu;
        var customSaveItem = viewer.jsObject.VerticalMenuItem(saveMenu, "myItemName", "test download zugferd", "emptyImage", "customItemKey");
        saveMenu.innerContent.appendChild(customSaveItem);

        customSaveItem.action = function () {
            saveMenu.changeVisibleState(false);

            var pdfExportSettings = new Stimulsoft.Report.Export.StiPdfExportSettings();
            pdfExportSettings.ZUGFeRDComplianceMode = Stimulsoft.Report.Export.StiPdfZUGFeRDComplianceMode.V2_1;
            pdfExportSettings.ZUGFeRDConformanceLevel = "EN 16931";
            pdfExportSettings.pdfACompliance = true;
            pdfExportSettings.pdfComplianceMode = Stimulsoft.Report.Export.StiPdfComplianceMode.A3;
            pdfExportSettings.ZUGFeRDInvoiceData = xmlFilePath;

            //Export to PDF
            report.exportDocumentAsync(function (pdfData) {
                //Save data to file
                Stimulsoft.System.StiObject.saveAs(pdfData, "your_file.pdf", "application/pdf");
            }, Stimulsoft.Report.StiExportFormat.Pdf, null, pdfExportSettings);
        }

        // Assigning a report to the Viewer:
        viewer.report = report;

    </script>
</head>
<body onload="onLoad();">
<div id="viewerContent"></div>
</body>
</html>
